Homework 1 Solution
================

``` r
library(tidyverse)
library(moderndive)
```

## Context

This assignment reinforces ideas in the [building
blocks](topic_building_blocks.html) topic.

## Due date and submission

Due: September 23 at 11:59pm.

Please submit (via courseworks) the web address of the GitHub repo
containing your work for this assignment; git commits after the due date
will cause the assignment to be considered late.

R Markdown documents included as part of your solutions must not install
packages, and should only load the packages necessary for your
submission to knit.

## Points

| Problem         | Points    |
|:----------------|:----------|
| Problem 0.1     | 25        |
| Problem 0.2     | 25        |
| Problem 1       | 25        |
| Problem 2       | 25        |
| Optional survey | No points |

## Problem 0.1

This solution focuses on a reproducible report containing code and text
necessary for Problems 1-3, and is organized as an R Project. This was
not prepared as a GitHub repo; examples for repository structure and git
commits should be familiar from other elements of the course.

## Problem 0.2

Throughout, we use appropriate text to describe our code and results,
and use clear styling to ensure code is readable.

## Problem 1

### Load dataset

The package is installed, and does not need to be reinstalled as part of
this document. The code below loads the data.

``` r
data("early_january_weather")
```

After loading, some data inspections are encouraged (e.g. using `view`
or reading a help file about the data). These are not included in this
document.

### Data description

The dataset contains 358 observations of hourly meterological data taken
over the first 15 days of January. Note that two observations appear to
be missing, since there are 360 hours in 15 days. The data include 15
variables. These indicate the origin (EWR airport), as well as several
variables indicating the observation day and time. The remaining
variables are meteorological, and include temperature, humidity,
precipitation, and others.

The mean temperature (rounded to the nearest degre F) in this dataset is
40 F.

Below is a scatterplot showing temperature over time, color coded by
humidity.

``` r
ggplot(early_january_weather, aes(x = time_hour, y = temp, color = humid)) + 
  geom_point()
```

![](p8105_hw1_ajg2202_files/figure-gfm/scatterplot-1.png)<!-- -->

``` r
ggsave("p8105_hw1p1_scatterplot.pdf")
```

    ## Saving 7 x 5 in image

Temperatures vary over the day, with lower temperatures at night.
Temperatures generally increased over the 15 day period, and between
January 12 through 14 humidity was higher; in this window the difference
between daytime and nighttime temperatures was smallest.

## Problem 2

### Create data frame

Below we create a tibble consisting of:

- a random sample of size 10 from a standard Normal distribution
- a logical vector indicating whether elements of the sample are greater
  than 0
- a character vector of length 10
- a factor vector of length 10, with 3 different factor “levels”

``` r
prob2_df = 
  tibble(
    samp = rnorm(10),
    samp_gt_0 = samp > 0,
    char_vec = c("a", "b", "c", "d", "e", "f", "g", "h", "i", "j"),
    factor_vec = factor(c("low", "low", "low", "mod", "mod", "mod", "mod", "high", "high", "high"))
  )
```

### Take the mean of each variable

When we try to take the mean of each variable:

- We are successful with the variable `samp` because it is a numeric
  value.
- We are successful with the variable `samp_gt_0` because R can
  interpret the logical vector as a vector of 0’s (FALSE’s) and 1’s
  (TRUE’s). The resulting mean is the proportion of TRUE values.
- We get warnings for the variables `char_vec` and `factor_vec` because
  neither are numeric nor logical, and can’t be interpreted as numeric.
  The resulting output is `NA`.

``` r
mean(pull(prob2_df, samp))
```

    ## [1] -0.009841379

``` r
mean(pull(prob2_df, samp_gt_0))
```

    ## [1] 0.6

``` r
mean(pull(prob2_df, char_vec))
```

    ## Warning in mean.default(pull(prob2_df, char_vec)): argument is not numeric or
    ## logical: returning NA

    ## [1] NA

``` r
mean(pull(prob2_df, factor_vec))
```

    ## Warning in mean.default(pull(prob2_df, factor_vec)): argument is not numeric or
    ## logical: returning NA

    ## [1] NA

### Convert variables to numeric

Next we apply the `as.numeric` function to the logical, character, and
factor variables.

- We successfully convert `samp_gt_0` to numeric, taking values of 0
  (FALSE) and 1 (TRUE).
- We cannot convert `char_vec` to numeric. The result is a warning and a
  vector of NA’s.
- We successfully convert `factor_vec` to numeric, taking values of 2
  for `"low"`, 3 for `"moderate"`, and 1 for `"high"`. Numeric values
  are assigned to the factor levels, which are alphabetical unless
  otherwise specified.

In short, R will try to convert variables from one type to another based
on what you’re asking it to do – but this does make some assumptions
about how e.g. factors should be converted to numeric variables. You can
be explicit about the conversion, as we are here, but taking the mean of
a variable implicitly does that conversion based on what R assumes you
want!

We show the code but not the output below by specifying code chunk
options `results="hide"`, `warning=FALSE`, and `message=FALSE`.

``` r
as.numeric(pull(prob2_df, samp))
as.numeric(pull(prob2_df, samp_gt_0))
as.numeric(pull(prob2_df, char_vec))
as.numeric(pull(prob2_df, factor_vec))
```

## Optional survey

Optional survey is optional.
